use crate::cmd::config::{AppConfig, APP_CONFIG};
use crate::ems;
use crate::internal::utils::mq::{RabbitMQ, MQ};
use clap::Parser;
use std::sync::Arc;
use tokio::fs::read_to_string;

#[derive(Parser, Debug)]
#[command(version, about, long_about = None)]
struct Args {
    #[arg(short, long, value_name = "EMU配置文件")]
    config: String,
}

pub async fn cmd() {
    let args = Args::parse();
    let result = init_system(args.config).await;
    if let Err(e) = result {
        eprintln!("系统初始化失败: {}", e.to_string());
    } else {
        let emu = Arc::new(ems::emu::emu::Emu::new().await);
        let _ = emu.run().await;
    }
}

/// 初始化系统资源以及配置
async fn init_system(config_path: String) -> anyhow::Result<()> {
    init_config(config_path).await?;
    let rabbitmq = RabbitMQ::new().await?;
    MQ.get_or_init(|| rabbitmq);
    Ok(())
}

/// 配置载入内存
async fn init_config(config_path: String) -> anyhow::Result<()> {
    let content = read_to_string(config_path).await?;
    let app_config: AppConfig = serde_yml::from_str(content.as_str())?;
    APP_CONFIG.set(app_config).expect("配置载入内存错误");
    Ok(())
}
