use crate::cmd::config::app_config;
use tklog::handle::FileMixedMode;
use tklog::{Format, LogOption, ASYNC_LOG, LEVEL};

#[inline]
pub async fn init_log(module: &str, filename: &str) {
    let level = if cfg!(debug_assertions) {
        Some(LEVEL::Debug)
    } else {
        Some(LEVEL::Info)
    };
    let console = if cfg!(debug_assertions) {
        Some(true)
    } else {
        Some(false)
    };
    ASYNC_LOG
        //兼容官方日志门面
        .uselog()
        .set_mod_option(
            //模块名称
            module,
            LogOption {
                //打印等级
                level,
                //控制台是否打印
                console,
                //格式化风格
                format: Some(Format::LevelFlag | Format::Microseconds),
                //格式化模板
                formatter: Some(String::from("{time} {level} {message}\n")),
                fileoption: Some(Box::new(FileMixedMode::new(
                    //日志文件名
                    format!("{}/{}", app_config().log.path, filename).as_str(),
                    //滚动字节数, 目前这里是512M
                    1 << 29,
                    //同时每天滚动
                    tklog::MODE::DAY,
                    //最多备份数, 30天
                    30,
                    //是否开启压缩
                    true,
                ))),
            },
        )
        .await;
}
