use crate::cmd::config::app_config;
use amqprs::connection::{Connection, OpenConnectionArguments};
use std::sync::OnceLock;

/// RabbitMQ 单例
pub static MQ: OnceLock<RabbitMQ> = OnceLock::new();

pub fn mq_conn() -> &'static RabbitMQ {
    MQ.get().unwrap()
}

pub struct RabbitMQ {
    pub conn: Connection,
}

impl RabbitMQ {
    pub async fn new() -> Result<Self, anyhow::Error> {
        let config = &app_config().rabbitmq;
        let conn = Connection::open(&OpenConnectionArguments::new(
            config.host.as_str(),
            config.port,
            config.username.as_str(),
            config.password.as_str(),
        ))
        .await?;
        Ok(RabbitMQ { conn })
    }
}
